import style from '../scss/style.scss';
import AreaDeDesenho from './areaDesenho/AreaDeDesenho.js';
import MenuSuperior from './menus/MenuSuperior.js';

/**
 * Classe App
 * 
 * Classe principal da aplicação. Realiza a instância dos elementos
 * que irão compor a aplicação
 * 
 * @author Robertino Mendes Santiago Jr <robertino@ufpr.br>
 */
export default class App {

    /**
     * Método construtor da classe App.
     * São criados neste construtor:
     * . o menu superior
     * . a área de desenho 
     */
    constructor() {
        this._menuSuperior = new MenuSuperior(this);
        this._areaDeDesenho = new AreaDeDesenho(this);
        this._objetos = new Array();
    }

    /**
     * Devolve o valor da propriedade menuSuperior
     * @return {MenuSuperior} Valor da propriedade menuSuperior
     */
    get menuSuperior() {
        return this._menuSuperior;
    }

    /**
     * Devolve o valor da propriedade areaDeDesenho
     * @return {AreaDeDesenho} Valor da propriedade areaDeDesenho
     */
    get areaDeDesenho() {
        return this._areaDeDesenho;
    }

    /**
     * Devolve o valor da propriedade objetos
     * @return {Array} Valor da propriedade objetos
     */
    get objetos() {
        return this._objetos;
    }

    /**
     * Atribui um valor recebido por parâmetro à propriedade objetos
     * @param {Array} objetos Objetos
     */
    set objetos(objetos) {
        this._objetos = objetos;
    }

}

/**
 * Cria a instância da classe App após o carregamento da página
 */
document.addEventListener('DOMContentLoaded', function(){
    const app = new App();
});